use clap::Parser;
use eternalfest_cli::{run, CliArgs};

#[tokio::main]
async fn main() {
  let args: CliArgs = CliArgs::parse();

  let res = run(&args).await;

  match res {
    Err(e) => {
      eprintln!("{}", e);
    }
    Ok(()) => {}
  }
}
